@@ -1322,10 +1322,6 @@ build_execute_command_in_context (BuildContext* context, GError **err)
 	/* Send options to make */
 	if (strcmp (build_program_get_basename (context->program), "make") == 0)
 	{
-		if (!anjuta_preferences_get_bool (prefs , PREF_TRANSLATE_MESSAGE))
-		{
-			build_program_add_env (context->program, "LANGUAGE", "C");
-		}
 		if (anjuta_preferences_get_bool (prefs , PREF_PARALLEL_MAKE))
 		{
 			gchar *arg = g_strdup_printf ("-j%d", anjuta_preferences_get_int (prefs , PREF_PARALLEL_MAKE_JOB));
@@ -1338,6 +1334,14 @@ build_execute_command_in_context (BuildContext* context, GError **err)
 		}
 	}
 	
+	/* Set a current working directory which can contains symbolic links */
+	build_program_add_env (context->program, "PWD", context->program->work_dir);
+
+	if (!anjuta_preferences_get_bool (prefs , PREF_TRANSLATE_MESSAGE))
+	{
+		build_program_add_env (context->program, "LANGUAGE", "C");
+	}
+	
 	build_program_override (context->program, context->environment);
 	
 	if (context->message_view)
@@ -1517,13 +1521,10 @@ build_save_distclean_and_execute_command (BasicAutotoolsPlugin* bplugin, BuildPr
 		// Need to run make clean before
 		if (!anjuta_util_dialog_boolean_question (GTK_WINDOW (ANJUTA_PLUGIN (bplugin)->shell), _("Before using this new configuration, the default one needs to be removed. Do you want to do that ?"), NULL))
 		{
-			GError *err;
-			
-			err = g_error_new (ianjuta_builder_error_quark (),
-									 IANJUTA_BUILDER_CANCELED,
-									 _("Command canceled by user"));
-			
-			build_program_callback (context->program, G_OBJECT (bplugin), context, err);
+			if (err)
+				*err = g_error_new (ianjuta_builder_error_quark (),
+				                   IANJUTA_BUILDER_CANCELED,
+				                   _("Command canceled by user"));
 			
 			return NULL;
 		}
@@ -2040,7 +2041,7 @@ build_configure_dialog (BasicAutotoolsPlugin *plugin, BuildFunc func, const gcha
 	
 		build_dir = g_file_get_path (file);
 		g_object_unref (file);
-	
+
 		args = build_configuration_get_args (config);
 		
 		if (run_autogen)
@@ -2136,7 +2137,7 @@ build_get_uri_configuration (BasicAutotoolsPlugin *plugin, const gchar *uri)
 	for (cfg = build_configuration_list_get_first (plugin->configurations); cfg != NULL; cfg = build_configuration_next (cfg))
 	{
 		const gchar *root = build_configuration_list_get_build_uri  (plugin->configurations, cfg);
-		gsize len = strlen (root);
+		gsize len = root != NULL ? strlen (root) : 0;
 
 		if ((len > uri_len) && (strncmp (uri, root, len) == 0))
 		{
@@ -2657,7 +2658,7 @@ update_project_ui (BasicAutotoolsPlugin *bb_plugin)
 	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
 								   "ActionBuildCleanProject");
-	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
+	g_object_set (G_OBJECT (action), "sensitive", has_makefile, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
 								   "ActionBuildDistribution");
 	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
