@@ -37,7 +37,8 @@
 #include <libanjuta/interfaces/ianjuta-file-loader.h>
 
 #include <glib.h>
-
+#include <stdlib.h>
+#include <unistd.h>
 #include <ctype.h>
 
 /*---------------------------------------------------------------------------*/
@@ -465,7 +466,7 @@ atp_output_context_print_command (ATPOutputContext *this, const gchar* command)
 	case ATP_TOUT_COMMON_PANE:
 	case ATP_TOUT_NEW_PANE:
 		/* Display the name of the command */
-		msg = g_strdup_printf(_("Running command: %s...\n"), command);	
+		msg = g_strdup_printf(_("Running command: %s…\n"), command);	
 		ok = atp_output_context_print (this, msg);
 		g_free (msg);
 		break;
@@ -625,7 +626,7 @@ atp_output_context_initialize (ATPOutputContext *this,
 		this->editor = get_current_editor(docman);
 		if (this->editor == NULL)
 		{
-			anjuta_util_dialog_warning (GTK_WINDOW (this->execution->plugin->shell), _("Unable to create a buffer, command aborted"));
+			anjuta_util_dialog_warning (GTK_WINDOW (this->execution->plugin->shell), _("Unable to create a buffer: command aborted"));
 			return NULL;
 		}
 		g_object_add_weak_pointer (G_OBJECT (this->editor), (gpointer *)(gpointer)&this->editor);
@@ -637,7 +638,7 @@ atp_output_context_initialize (ATPOutputContext *this,
 		this->editor = docman == NULL ? NULL : IANJUTA_EDITOR( ianjuta_document_manager_get_current_document (docman, NULL));
 		if (this->editor == NULL)
 		{
-			anjuta_util_dialog_warning (GTK_WINDOW (this->execution->plugin->shell), _("No document currently open, command aborted"));
+			anjuta_util_dialog_warning (GTK_WINDOW (this->execution->plugin->shell), _("No document currently open: command aborted"));
 			return NULL;
 		}
 		g_object_add_weak_pointer (G_OBJECT (this->editor), (gpointer *)(gpointer)&this->editor);
@@ -813,7 +814,7 @@ atp_execution_context_execute (ATPExecutionContext* this,
 	/* Change working directory */
 	if (this->directory != NULL)
 	{
-		prev_dir = g_get_current_dir();
+		prev_dir = anjuta_util_get_current_dir();
 		chdir (this->directory);
 	}
 	/* Execute */
@@ -977,7 +978,7 @@ atp_user_tool_execute (GtkMenuItem *item, ATPUserTool* this)
 		/* Run in a terminal */
 		/* don't need a execution context, launch and forget */
 
-		gnome_execute_terminal_shell (dir, cmd);
+		anjuta_util_execute_terminal_shell (dir, cmd);
 	}
 	else
 	{
