@@ -34,6 +34,7 @@
 #include <libanjuta/resources.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-file-loader.h>
+#include <libxml/parser.h>
 
 #include "anjuta.h"
 
@@ -55,6 +56,18 @@ static gboolean proper_shutdown = 0;
 static gchar *anjuta_geometry = NULL;
 static gchar **anjuta_filenames = NULL;
 
+static gboolean
+show_version_cb (const char *option_name,
+				const char *value,
+				gpointer data,
+				GError **error)
+{
+	g_print ("%s\n", PACKAGE_STRING);
+	exit (0);
+
+	return TRUE;
+}
+
 static const GOptionEntry anjuta_options[] = {
 	{
 		"geometry", 'g', 0, G_OPTION_ARG_STRING,
@@ -94,6 +107,12 @@ static const GOptionEntry anjuta_options[] = {
 		N_("Shut down Anjuta properly, releasing all resources (for debugging)"),
 		NULL
 	},
+	{
+		"version", 'v', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK,
+		&show_version_cb,
+		("Display program version"),
+		NULL
+	},
 	{
 		G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY,
 		&anjuta_filenames,
@@ -176,7 +195,7 @@ main (int argc, char *argv[])
 	/* Initialize gnome program */
 	if (!g_option_context_parse (context, &argc, &argv, &error))
 	{
-		DEBUG_PRINT ("Option parsing failed: %s", error->message);
+		g_debug ("Option parsing failed: %s", error->message);
 		exit(1);
 	}
 	
@@ -191,8 +210,7 @@ main (int argc, char *argv[])
 		gchar** filename;
 		for (filename = anjuta_filenames; *filename != NULL; filename++)
 		{
-			GFile* file = g_file_new_for_commandline_arg(*filename);
-
+			GFile* file = anjuta_util_file_new_for_commandline_arg(*filename);
 			g_free (*filename);
 			*filename = g_file_get_uri (file);
 			g_object_unref (file);
@@ -223,7 +241,7 @@ main (int argc, char *argv[])
 			if (response == UNIQUE_RESPONSE_OK)
 				return 0;
 			else
-				DEBUG_PRINT("Faild to contact first instance, starting up normally");
+				DEBUG_PRINT("Failed to contact first instance, starting up normally");
 		}
 	}
 	
@@ -247,5 +265,9 @@ main (int argc, char *argv[])
 	gtk_widget_show (GTK_WIDGET (app));
 	gtk_main();
 	
+	/* xmlCleanupParser must be called only one time in the application */
+	if (proper_shutdown) 
+		xmlCleanupParser ();
+
 	return 0;
 }
